********************************************************************************
compas_rcf
********************************************************************************

python module for MAS DFAB project Rapid Clay Formations

COMPAS
======

compas_rcf is part is built on top of `compas`_, `compas_fab`_ and
`compas_rrc`_.

Note on compatibility
=====================

Installation of the package requires Python \>\= 3.6.

Big parts are compatible with IronPython 2.7 (to be run inside Rhino plugin
Grasshopper).

The modules that require Python \>\= 3.6 should raise an exception on import.

Documentation
=============

.. toctree::
   :maxdepth: 3
   :titlesonly:

   getting_started
   examples
   known_issues
   contributing
   reference
   changelog
   authors
   license

.. _`compas`: https://compas-dev.github.io/
.. _`compas_fab`: https://gramaziokohler.github.io/compas_fab/
.. _`compas_rrc`: https://bitbucket.org/ethrfl/compas_rrc/
